@@ -69,6 +69,6 @@ efficiencies.dea <-
       stop("No efficiency/beta/delta/objval parameters in this solution!")
     }
     
-    return(round(eff, 6))
+    return(eff)
     
 }
\ No newline at end of file
